@@ -32,7 +32,17 @@ sub SKIP_CLASS {
         for my $req (@reqs) {
             local $@;
 
-            my $ok = ref($req) ? eval { $req->(); 1 } : eval "require $req; 1";
+            my $ok;
+
+            if ('CODE' eq ref($req)) {
+                $ok = eval { $req->(); 1 };
+            }
+            elsif ('ARRAY' eq ref $req) {
+                $ok = eval "use @$req; 1";
+            }
+            else {
+                $ok = eval "use $req; 1";
+            }
 
             return $@ if !$ok;
         }
